@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -33,22 +33,26 @@ from twisted import logger
 from twisted.logger import ILogObserver
 from zope.interface import provider
 
+
 # some library you use is using txaio logging stuff
 class Library(object):
     log = txaio.make_logger()
 
     def something(self):
-        self.log.info("info log from library foo={foo}", foo='bar')
+        self.log.info("info log from library foo={foo}", foo="bar")
         self.log.debug("debug information")
 
+
 # lets say you start your own observer
 @provider(ILogObserver)
 class Observer(object):
     def __init__(self):
         self._out = sys.stdout
+
     def __call__(self, event):
         self._out.write("Observe: {}\n".format(event))
 
+
 lib = Library()
 print("logging not started")
 logger.globalLogBeginner.beginLoggingTo([Observer()])
