@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,8 +24,7 @@
 #
 ###############################################################################
 
-from __future__ import absolute_import, division, print_function
-
+import io
 import os
 import sys
 import weakref
@@ -44,8 +43,12 @@ from txaio.interfaces import IFailedFuture, ILogger, log_levels
 from txaio._iotype import guess_stream_needs_encoding
 from txaio import _Config
 from txaio._common import _BatchedTimer
+from txaio import _util
+from twisted.logger import Logger as _Logger, formatEvent, ILogObserver
+from twisted.logger import globalLogBeginner, formatTime, LogLevel
 
-import six
+from twisted.internet.defer import ensureDeferred
+from asyncio import iscoroutinefunction
 
 using_twisted = True
 using_asyncio = False
@@ -59,67 +62,15 @@ _stderr, _stdout = sys.stderr, sys.stdout
 # time as start_logging is called (with the desired log-level) and
 # then we call _set_log_level on each instance. After that,
 # Logger's ctor uses _log_level directly.
-_observer = None     # for Twisted legacy logging support; see below
+_observer = None  # for Twisted legacy logging support; see below
 _loggers = weakref.WeakSet()  # weak-references of each logger we've created
-_log_level = 'info'  # global log level; possibly changed in start_logging()
+_log_level = "info"  # global log level; possibly changed in start_logging()
 _started_logging = False
 
 _categories = {}
 
 IFailedFuture.register(Failure)
-
-_NEW_LOGGER = False
-try:
-    # Twisted 15+
-    from twisted.logger import Logger as _Logger, formatEvent, ILogObserver
-    from twisted.logger import globalLogBeginner, formatTime, LogLevel
-    ILogger.register(_Logger)
-    _NEW_LOGGER = True
-
-except ImportError:
-    # we still support Twisted 12 and 13, which doesn't have new-logger
-    from zope.interface import Interface
-    from datetime import datetime
-    import time
-
-    # provide our own simple versions of what Twisted new-logger does
-
-    class ILogObserver(Interface):
-        pass
-
-    def formatTime(t):  # noqa
-        dt = datetime.fromtimestamp(t)
-        return six.u(dt.strftime("%Y-%m-%dT%H:%M:%S%z"))
-
-    def formatEvent(event):  # noqa
-        msg = event['log_format']
-        return msg.format(**event)
-
-    class LogLevel:
-        critical = 'critical'
-        error = 'error'
-        warn = 'warn'
-        info = 'info'
-        debug = 'debug'
-        trace = 'trace'
-
-        @classmethod
-        def lookupByName(cls, name):  # noqa
-            return getattr(cls, name)
-
-    class _Logger(ILogger):
-        def __init__(self, **kwargs):
-            self.namespace = kwargs.get('namespace', None)
-
-        def emit(self, level, format='', **kwargs):
-            kwargs['log_time'] = time.time()
-            kwargs['log_level'] = level
-            kwargs['log_format'] = format
-            kwargs['log_namespace'] = self.namespace
-            # NOTE: the other loggers are ignoring any log messages
-            # before start_logging() as well
-            if _observer:
-                _observer(kwargs)
+ILogger.register(_Logger)
 
 
 def _no_op(*args, **kwargs):
@@ -131,7 +82,6 @@ def add_log_categories(categories):
 
 
 def with_config(loop=None):
-    global config
     if loop is not None:
         if config.loop is not None and config.loop is not loop:
             raise RuntimeError(
@@ -205,27 +155,28 @@ class Logger(object):
         # level, we bind to the no_op method
         desired_index = log_levels.index(level)
 
-        for (idx, name) in enumerate(log_levels):
-            if name == 'none':
+        for idx, name in enumerate(log_levels):
+            if name == "none":
                 continue
 
             if idx > desired_index:
                 current = getattr(self, name, None)
                 if not current == _no_op or current is None:
                     setattr(self, name, _no_op)
-                if name == 'error':
-                    setattr(self, 'failure', _no_op)
+                if name == "error":
+                    setattr(self, "failure", _no_op)
 
             else:
                 if getattr(self, name, None) in (_no_op, None):
 
-                    if name == 'trace':
+                    if name == "trace":
                         setattr(self, "trace", self._trace)
                     else:
-                        setattr(self, name,
-                                partial(self._log, LogLevel.lookupByName(name)))
+                        setattr(
+                            self, name, partial(self._log, LogLevel.lookupByName(name))
+                        )
 
-                    if name == 'error':
+                    if name == "error":
                         setattr(self, "failure", self._failure)
 
         self._log_level = level
@@ -247,15 +198,14 @@ def make_logger(level=None, logger=_Logger, observer=None):
     if "self" in cf.f_locals:
         # We're probably in a class init or method
         cls = cf.f_locals["self"].__class__
-        namespace = '{0}.{1}'.format(cls.__module__, cls.__name__)
+        namespace = "{0}.{1}".format(cls.__module__, cls.__name__)
     else:
         namespace = cf.f_globals["__name__"]
         if cf.f_code.co_name != "<module>":
             # If it's not the module, and not in a class instance, add the code
             # object's name.
             namespace = namespace + "." + cf.f_code.co_name
-    logger = Logger(level=level, namespace=namespace, logger=logger,
-                    observer=observer)
+    logger = Logger(level=level, namespace=namespace, logger=logger, observer=observer)
     return logger
 
 
@@ -266,13 +216,14 @@ class _LogObserver(object):
 
     An observer which formats events to a given file.
     """
+
     to_tx = {
-        'critical': LogLevel.critical,
-        'error': LogLevel.error,
-        'warn': LogLevel.warn,
-        'info': LogLevel.info,
-        'debug': LogLevel.debug,
-        'trace': LogLevel.debug,
+        "critical": LogLevel.critical,
+        "error": LogLevel.error,
+        "warn": LogLevel.warn,
+        "info": LogLevel.info,
+        "debug": LogLevel.debug,
+        "trace": LogLevel.debug,
     }
 
     def __init__(self, out):
@@ -296,41 +247,41 @@ class _LogObserver(object):
         # on it, the log_format will be None for the traceback after
         # "Unhandled error in Deferred" -- perhaps this is a Twisted
         # bug?
-        if event['log_format'] is None:
-            msg = u'{0} {1}{2}'.format(
+        if event["log_format"] is None:
+            msg = "{0} {1}{2}".format(
                 formatTime(event["log_time"]),
-                failure_format_traceback(event['log_failure']),
+                failure_format_traceback(event["log_failure"]),
                 os.linesep,
             )
             if self._encode:
-                msg = msg.encode('utf8')
+                msg = msg.encode("utf8")
             self._file.write(msg)
         else:
             # although Logger will already have filtered out unwanted
             # levels, bare Logger instances from Twisted code won't have.
-            if 'log_level' in event and self._acceptable_level(event['log_level']):
-                msg = u'{0} {1}{2}'.format(
+            if "log_level" in event and self._acceptable_level(event["log_level"]):
+                msg = "{0} {1}{2}".format(
                     formatTime(event["log_time"]),
                     formatEvent(event),
                     os.linesep,
                 )
                 if self._encode:
-                    msg = msg.encode('utf8')
+                    msg = msg.encode("utf8")
 
                 self._file.write(msg)
 
 
-def start_logging(out=_stdout, level='info'):
+def start_logging(out=_stdout, level="info"):
     """
     Start logging to the file-like object in ``out``. By default, this
     is stdout.
     """
-    global _loggers, _observer, _log_level, _started_logging
+    global _observer, _log_level, _started_logging
 
     if level not in log_levels:
         raise RuntimeError(
             "Invalid log level '{0}'; valid are: {1}".format(
-                level, ', '.join(log_levels)
+                level, ", ".join(log_levels)
             )
         )
 
@@ -345,15 +296,10 @@ def start_logging(out=_stdout, level='info'):
     if out:
         _observer = _LogObserver(out)
 
-    if _NEW_LOGGER:
-        _observers = []
-        if _observer:
-            _observers.append(_observer)
-        globalLogBeginner.beginLoggingTo(_observers)
-    else:
-        assert out, "out needs to be given a value if using Twisteds before 15.2"
-        from twisted.python import log
-        log.startLogging(out)
+    _observers = []
+    if _observer:
+        _observers.append(_observer)
+    globalLogBeginner.beginLoggingTo(_observers)
 
 
 _unspecified = object()
@@ -370,7 +316,7 @@ class _TxApi(object):
         returns a unicode error-message
         """
         try:
-            return u'{0}: {1}'.format(
+            return "{0}: {1}".format(
                 fail.value.__class__.__name__,
                 fail.getErrorMessage(),
             )
@@ -390,17 +336,17 @@ class _TxApi(object):
         returns a string
         """
         try:
-            f = six.StringIO()
+            f = io.StringIO()
             fail.printTraceback(file=f)
             return f.getvalue()
         except Exception:
-            return u"Failed to format failure traceback for '{0}'".format(fail)
+            return "Failed to format failure traceback for '{0}'".format(fail)
 
-    def create_future(self, result=_unspecified, error=_unspecified):
+    def create_future(self, result=_unspecified, error=_unspecified, canceller=None):
         if result is not _unspecified and error is not _unspecified:
             raise ValueError("Cannot have both result and error.")
 
-        f = Deferred()
+        f = Deferred(canceller=canceller)
         if result is not _unspecified:
             resolve(f, result)
         elif error is not _unspecified:
@@ -414,6 +360,12 @@ class _TxApi(object):
         return fail(create_failure(error))
 
     def as_future(self, fun, *args, **kwargs):
+        # Twisted doesn't automagically deal with coroutines on Py3
+        if iscoroutinefunction(fun):
+            try:
+                return ensureDeferred(fun(*args, **kwargs))
+            except TypeError as e:
+                return create_future_error(e)
         return maybeDeferred(fun, *args, **kwargs)
 
     def is_future(self, obj):
@@ -444,7 +396,8 @@ class _TxApi(object):
             return self._get_loop().callLater(delay, fun, *args, **kwargs)
 
         return _BatchedTimer(
-            bucket_seconds * 1000.0, chunk_size,
+            bucket_seconds * 1000.0,
+            chunk_size,
             seconds_provider=get_seconds,
             delayed_call_creator=create_delayed_call,
         )
@@ -465,6 +418,9 @@ class _TxApi(object):
                 raise RuntimeError("reject requires a Failure or Exception")
         future.errback(error)
 
+    def cancel(self, future, msg=None):
+        future.cancel()
+
     def create_failure(self, exception=None):
         """
         Create a Failure instance.
@@ -494,7 +450,7 @@ class _TxApi(object):
     def gather(self, futures, consume_exceptions=True):
         def completed(res):
             rtn = []
-            for (ok, value) in res:
+            for ok, value in res:
                 rtn.append(value)
                 if not ok and not consume_exceptions:
                     value.raiseException()
@@ -532,6 +488,7 @@ class _TxApi(object):
         # possible in case someone is installing a custom one.
         if self._config.loop is None:
             from twisted.internet import reactor
+
             self._config.loop = reactor
         return self._config.loop
 
@@ -567,7 +524,10 @@ make_batched_timer = _default_api.make_batched_timer
 is_called = _default_api.is_called
 resolve = _default_api.resolve
 reject = _default_api.reject
+cancel = _default_api.cancel
 create_failure = _default_api.create_failure
 add_callbacks = _default_api.add_callbacks
 gather = _default_api.gather
 sleep = _default_api.sleep
+time_ns = _util.time_ns
+perf_counter_ns = _util.perf_counter_ns
